==> bumpster-0.1.6.tar.gz: bumpster-0.1.6/README.md <==
# bumpster

Yet another python version program.

I needed a method to automate and centralize my versioning for many different project types.  This is what I came up with.

## Install

Install the bumpster package via pypi

```shell
pip install bumpster
```

We have also maintained a single file, no dependency architecture to facilitate one off installs, etc

```shell
curl -o bump.py https://github.com/jthop/bumpster/bumpster/cli.py
```
`
## Config

Config is done via the .bumpster file in your project's root diarectory.  This filename can be overwridden using the --config-file option.

Sample .bumpster file

```ini
[version]
current = 0.1.6+build.40

[options]
auto-tag = True
auto-commit = True
auto-push = True
signature = True

[file1]
file = ./bumpster/__init__.py
style = semantic
regex = __version__\s*=\s*(?P<quote>[\'\"])(?P<version>.+)(?P=quote)

```

## Use


```shell
bump [options] PART
```

#### `PART`
  _**required**_

The PART would be: The segment of the semantic version to increase.  
Choices are [*major*, *minor*, *patch*, *prerelease*, *build*]


## Command line options

The output and parsing of `bump` can be controlled with the following options.

| Name                   | Description                                                  |
| -------------          | -------------                                                |
| `--verbose`            | To aid in your debugging, verbose prints all messages.       |
| `--dry-run`            | Useful if used WITH --verbose, will not modify any files.    |
| `--version`            | This will displpay the current version of bumpster.          |
| `--config-file` FILE   | Use FILE as config file instead of ./.bumpster               |
| `--defaults`           | Will configure bumpster with default settings. [^1]          |
| `--currrent`           | Display the current full version.                            |
| `--public`             | Display the version in format: MAJOR.MINOR.PATCH (1.2.3)     |
| `--pep440`             | Display a version that conforms with pep440                  |
| `--canonical`          | Test if the pep440 version conforms to pypi's specs          |
| `--git`                | *Version composed of a git tag, commit sha, and distance* [^2] |  


## Examples

```shell
$ bump --current
0.2.7-beta.3+build.99

# Lets run a build.  Bump with no arguments defaults to bump the build number.
$ bump
0.2.7-beta.3+build.100

# Now its release time.  Lets bump the minor
$ bump minor
0.3.0+build.101

# If we wanted to use the version to build a package for pypi
$ bump --public
0.3.0

# Oh no a bug, let's patch
$ bump patch
0.3.1+build.102

# Finally, our long awaited 1.0 release.
$ bump major
1.0.0+build.103

# Of course, our 1.0 release will be on pypi
$ bump --public
1.0.0
```

[^1]: The defaults are version '0.1.0' with auto-tag and auto-commit OFF.  For files to modify, all *.py files are searched for a __version__ string.
[^2]: This option has not yet been implemented.

==> bumpster-0.1.11.tar.gz: bumpster-0.1.11/README.md <==
# bumpster

Yet another python version program.

I needed a method to automate and centralize my versioning for many different project types.  This is what I came up with.

## Install ##

Install the bumpster package via pypi

```shell
pip install bumpster
```

We have also maintained a single file, no dependency architecture to facilitate one off installs, etc

```shell
curl -o bump.py https://github.com/jthop/bumpster/bumpster/cli.py
```
`
## Config ##

Config is done via the .bumpster file in your project's root diarectory.  This filename can be overwridden using the --config-file option.

Sample .bumpster file

```ini
[version]
current = 0.1.6+build.40

[options]
auto-tag = True
auto-commit = True
auto-push = True
signature = True

[file1]
file = ./bumpster/__init__.py
style = semantic
regex = __version__\s*=\s*(?P<quote>[\'\"])(?P<version>.+)(?P=quote)

```

### Command line options

The output and parsing of `bump` can be controlled with the following options.

| Name                   | Description                                                  |
| -------------          | -------------                                                |
| `--verbose`            | To aid in your debugging, verbose prints all messages.       |
| `--dry-run`            | Useful if used WITH --verbose, will not modify any files.    |
| `--version`            | This will displpay the current version of bumpster.          |
| `--config-file` FILE   | Use FILE as config file instead of ./.bumpster               |
| `--defaults`           | Will configure bumpster with default settings. [^1]          |
| `--currrent`           | Display the current full version.                            |
| `--public`             | Display the version in format: MAJOR.MINOR.PATCH (1.2.3)     |
| `--pep440`             | Display a version that conforms with pep440                  |
| `--canonical`          | Test if the pep440 version conforms to pypi's specs          |
| `--git`                | *Version composed of a git tag, commit sha, and distance* [^2] |  


## Use ##

First thing to notice, although we're named bumpster, the cli command is bump

```shell
bump SEGMENT
```
The SEGMENT would be: *major*, *minor*, *patch*, *prerelease*, *build*

#### Examples

```shell
$ bump --current
0.2.7-beta.3+build.99

# Lets run a build.  Bump with no arguments defaults to bump the build number.
$ bump
0.2.7-beta.3+build.100

# Now its release time.  Lets bump the minor
$ bump minor
0.3.0+build.101

# If we wanted to use the version to build a package for pypi
$ bump --public
0.3.0

# Oh no a bug, let's patch
$ bump patch
0.3.1+build.102

# Finally, our long awaited 1.0 release.
$ bump major
1.0.0+build.103

# Of course, our 1.0 release will be on pypi
$ bump --public
1.0.0
```

[^1]: The defaults are version '0.1.0' with auto-tag and auto-commit OFF.  For files to modify, all *.py files are searched for a __version__ string.
[^2]: This option has not yet been implemented.
